==> activiti-rest-5.22.0-sources.jar: org/activiti/rest/service/api/runtime/process/ExecutionActionRequest.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.activiti.rest.service.api.runtime.process;

import java.util.List;

import org.activiti.rest.service.api.RestActionRequest;
import org.activiti.rest.service.api.engine.variable.RestVariable;

import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeInfo.Id;

/**
 * @author Frederik Heremans
 */
public class ExecutionActionRequest extends RestActionRequest {

  public static final String ACTION_SIGNAL = "signal";
  public static final String ACTION_SIGNAL_EVENT_RECEIVED = "signalEventReceived";
  public static final String ACTION_MESSAGE_EVENT_RECEIVED = "messageEventReceived";
  
  protected String signalName;
  protected String messageName;
  protected List<RestVariable> variables;
  
  public void setVariables(List<RestVariable> variables) {
    this.variables = variables;
  }
  
  @JsonTypeInfo(use=Id.CLASS, defaultImpl=RestVariable.class)
  public List<RestVariable> getVariables() {
    return variables;
  }
  
  public String getSignalName() {
    return signalName;
  }
  
  public void setSignalName(String signalName) {
    this.signalName = signalName;
  }
  
  public String getMessageName() {
    return messageName;
  }
  
  public void setMessageName(String messageName) {
    this.messageName = messageName;
  }
}

==> activiti-rest-6.0.0-sources.jar: org/activiti/rest/service/api/runtime/process/ExecutionActionRequest.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.activiti.rest.service.api.runtime.process;

import java.util.List;

import org.activiti.rest.service.api.RestActionRequest;
import org.activiti.rest.service.api.engine.variable.RestVariable;

import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeInfo.Id;

/**
 * @author Frederik Heremans
 */
public class ExecutionActionRequest extends RestActionRequest {

  public static final String ACTION_SIGNAL = "signal";
  public static final String ACTION_TRIGGER = "trigger";
  public static final String ACTION_SIGNAL_EVENT_RECEIVED = "signalEventReceived";
  public static final String ACTION_MESSAGE_EVENT_RECEIVED = "messageEventReceived";

  protected String signalName;
  protected String messageName;
  protected List<RestVariable> variables;
  protected List<RestVariable> transientVariables;

  public void setVariables(List<RestVariable> variables) {
    this.variables = variables;
  }

  @JsonTypeInfo(use = Id.CLASS, defaultImpl = RestVariable.class)
  public List<RestVariable> getVariables() {
    return variables;
  }
  
  public void setTransientVariables(List<RestVariable> transientVariables) {
    this.transientVariables = transientVariables;
  }
  
  @JsonTypeInfo(use = Id.CLASS, defaultImpl = RestVariable.class)
  public List<RestVariable> getTransientVariables() {
    return transientVariables;
  }

  public String getSignalName() {
    return signalName;
  }

  public void setSignalName(String signalName) {
    this.signalName = signalName;
  }

  public String getMessageName() {
    return messageName;
  }

  public void setMessageName(String messageName) {
    this.messageName = messageName;
  }
}
